@@ -404,7 +404,7 @@ def argument_parser():
     group.add_argument("--min-repeat-count", "-r", type=int, metavar="N", default=2500,
         help="Minimal number of occurences at which a qgram is "
         "marked as repetetive and ignored. For the human reference genome, "
-        "this should be set to 2500 for a good sensitivity/speed ratio.")
+        "this should be set to 2500 for a good sensitivity/speed ratio (default 2500).")
 
     mapping = subparsers.add_parser("map", help="Perform the mapping.")
 
@@ -414,7 +414,7 @@ def argument_parser():
             "or FASTQ files (i.e. sequence reads).")
     group.add_argument("mates", nargs="?",
         help="Mate-pair or paired-end sequences to map as FASTA or FASTQ files.")
-    group.add_argument("index", help="Indexed reference sequences as HDF5.")
+    group.add_argument("reference", help="Path to indexed reference sequences as HDF5 or, alternatively path to reference fasta. In the latter case, the index is expected at path/to/ref.hdf5 if path/to/ref.fasta is the given reference.")
 
     group = mapping.add_argument_group("input file parameters")
     group.add_argument("--paired", "-p", action="store_true", help="Assume first input is interleaved fastq file.")
@@ -490,9 +490,14 @@ def main(profile=False):
             if paired and query_buffer % 2:
                 query_buffer += 1
 
+            if args.reference.endswith("hdf5"):
+                index = args.reference
+            else:
+                index = re.sub("(\.fasta\.gz|\.fasta)$", ".hdf5", args.reference)
+
             map_queries(
                 args.queries,
-                args.index,
+                index,
                 matespath=args.mates,
                 min_score=args.percent_identity,
                 strata=strata,
